# Hydrosphere Serving SDK

This package contains python API built on top of existing CLI code.

This package's purpose is to provide a simple and convenient way
of integrating user's workflow scripts with Serving API.